BLE Application to open a Garage door

Dependencies:   BLE_API Crypto RNG mbed nRF51822

Fork of BLE_LED by Bluetooth Low Energy

Revision:
15:88ea59cb2b9e
Parent:
12:eaee29bfa1c7
--- a/GaragemService.h	Sun Aug 30 01:10:16 2015 +0000
+++ b/GaragemService.h	Mon May 01 00:33:07 2017 +0000
@@ -49,10 +49,10 @@
 
         DBG("TS=%lu\tID=%c%c%c%c\tSYSKEY=%s\r\n", *((uint32_t *) msg), msg[4], msg[5], msg[6], msg[7], &msg[8]); 
 
         //check we are not a victim of a repetion attack
         DBG("%lu\t>=\t%lu\r\n", history.last_ts(), *((uint32_t*) &msg[0]));
         if(history.last_ts() >= *((uint32_t *) &msg[0])) {
-            DBG("HA HA repetion here...\r\n");
+            DBG("HA HA repetition here...\r\n");
             return GARAGEM_ERROR_REPETITION_ATTACK;
         }
@@ -49,10 +49,10 @@
         DBG("TS=%lu\tID=%c%c%c%c\tSYSKEY=%s\r\n", *((uint32_t *) msg), msg[4], msg[5], msg[6], msg[7], &msg[8]); 
 
-        //check we are not a victim of a repetion attack
+        //check we are not a victim of a repetition attack
         DBG("%lu\t>=\t%lu\r\n", history.last_ts(), *((uint32_t*) &msg[0]));
         if(history.last_ts() >= *((uint32_t *) &msg[0])) {